.. _trojanvision.defenses.backdoor:

backdoor
=========

.. currentmodule:: trojanvision.defenses

.. toctree::
   :maxdepth: 2

   attack_agnostic
   input_filtering
   training_filtering
   model_inspection
